==> pgmarket-1.5.0.tar.gz: pgmarket-1.5.0/header.php <==
<?
/* (c) 2001 Marco Pratesi <pratesi@telug.it> */

if ($SESSION["layersmenu_used"])
	include ($CFG->libdir."/layersmenu-header.inc.php");

$t = new Template();
$t->set_file(array("page" => "$CFG->templatedir"."header.ihtml"));
require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
$t->set_block("page", "is_logged_in", "is_logged_in_blck");
$t->set_var(array("is_logged_in_blck" => ""));
$t->set_block("page", "is_not_logged_in", "is_not_logged_in_blck");
$t->set_var(array("is_not_logged_in_blck" => ""));
$t->set_block("page", "layersmenu_used", "layersmenu_used_blck");
$t->set_var(array("layersmenu_used_blck" => ""));
$t->set_block("page", "frames_used", "frames_used_blck");
$t->set_var(array("frames_used_blck" => ""));
$t->set_block("page", "frames_not_used", "frames_not_used_blck");
$t->set_var(array("frames_not_used_blck" => ""));
$t->set_block("page", "layersmenu_used_bis", "layersmenu_used_bis_blck");
$t->set_var(array("layersmenu_used_bis_blck" => ""));
$t->set_block("page", "layersmenu_not_used_bis", "layersmenu_not_used_bis_blck");
$t->set_var(array("layersmenu_not_used_bis_blck" => ""));
$t->set_block("page", "is_logged_in_admin", "is_logged_in_admin_blck");
$t->set_var(array("is_logged_in_admin_blck" => ""));
$t->set_block("page", "weight_used", "weight_used_blck");
$t->set_var(array("weight_used_blck" => ""));
$t->set_block("page", "delivery_used", "delivery_used_blck");
$t->set_var(array("delivery_used_blck" => ""));
$t->set_block("page", "is_logged_in_horbartop", "is_logged_in_horbartop_blck");
$t->set_var(array("is_logged_in_horbartop_blck" => ""));
$t->set_var(array(
		"DOC_TITLE"			=> ov($t->get_var($DOC_TITLE)),
		"wwwroot"			=> $CFG->wwwroot,
		"images"			=> $CFG->images,
		"firstpage"			=> $CFG->firstpage,
		"cart_itemcount"		=> $CART->itemcount(),
		"cart_total"			=> $CART->total,
		"cart_ftotal"			=> formatted_price($CART->total),
		"current_stringtsf"		=> $stringtsf,
		"concatenation_checked_or"	=> $concatenation != "AND" ? "checked" : "",
		"concatenation_checked_and"	=> $concatenation == "AND" ? "checked" : "",
		"case_sensitive_checked"	=> $case_sensitive == "yes" ? "checked" : ""
));
if (is_logged_in())
	$t->parse("is_logged_in_blck", "is_logged_in", true);
else
	$t->parse("is_not_logged_in_blck", "is_not_logged_in", true);
if ($SESSION["layersmenu_used"]) {
	$t->set_var("firstleveltable", $firstleveltable);
	$t->parse("layersmenu_used_blck", "layersmenu_used", true);
}
if ($SESSION["frames_used"])
	$t->parse("frames_used_blck", "frames_used", true);
else
	$t->parse("frames_not_used_blck", "frames_not_used", true);
if ($SESSION["layersmenu_used"])
	$t->parse("layersmenu_used_bis_blck", "layersmenu_used_bis", true);
else
	$t->parse("layersmenu_not_used_bis_blck", "layersmenu_not_used_bis", true);
if (is_logged_in() && has_priv("admin"))
	$t->parse("is_logged_in_admin_blck", "is_logged_in_admin", true);
if ($SESSION["weight_used"]) {
	$t->set_var(array(
			"cart_weight"	=> $CART->weight,
			"cart_fweight"	=> formatted_weight($CART->weight)
	));
	$t->parse("weight_used_blck", "weight_used", true);
}
if ($SESSION["delivery_used"]) {
	$t->set_var(array(
			"cart_delivery"		=> $CART->delivery,
			"cart_fdelivery"	=> formatted_price($CART->delivery)
	));
	$t->parse("delivery_used_blck", "delivery_used", true);
}
if (is_logged_in()) {
	$t->set_var(array(
			"session_user_firstname"	=> o($SESSION["user"]["firstname"]),
			"session_user_lastname"		=> o($SESSION["user"]["lastname"])
	));
	$t->parse("is_logged_in_horbartop_blck", "is_logged_in_horbartop", true);
}
$t->pparse("out", "page");
//include("$CFG->templatedir"."header.ihtml");

?>

==> pgmarket-1.5.2.tar.gz: pgmarket-1.5.2/header.php <==
<?php
/* (c) 2001 Marco Pratesi <pratesi@telug.it> */

if ($SESSION["layersmenu_used"])
	include ("$CFG->libdir" . "/layersmenu-header.inc.php");

$t = new Template();
$t->set_file(array("page" => "$CFG->templatedir" . "header.ihtml"));
include ("$CFG->localelangdir" . "/global-common.inc.php");
include ("$CFG->localelangdir" . "/global-admin.inc.php");
$t->set_block("page", "is_logged_in", "is_logged_in_blck");
$t->set_var(array("is_logged_in_blck" => ""));
$t->set_block("page", "is_not_logged_in", "is_not_logged_in_blck");
$t->set_var(array("is_not_logged_in_blck" => ""));
$t->set_block("page", "layersmenu_used", "layersmenu_used_blck");
$t->set_var(array("layersmenu_used_blck" => ""));
$t->set_block("page", "frames_used", "frames_used_blck");
$t->set_var(array("frames_used_blck" => ""));
$t->set_block("page", "frames_not_used", "frames_not_used_blck");
$t->set_var(array("frames_not_used_blck" => ""));
$t->set_block("page", "layersmenu_used_bis", "layersmenu_used_bis_blck");
$t->set_var(array("layersmenu_used_bis_blck" => ""));
$t->set_block("page", "layersmenu_not_used_bis", "layersmenu_not_used_bis_blck");
$t->set_var(array("layersmenu_not_used_bis_blck" => ""));
$t->set_block("page", "is_logged_in_admin", "is_logged_in_admin_blck");
$t->set_var(array("is_logged_in_admin_blck" => ""));
$t->set_block("page", "weight_used", "weight_used_blck");
$t->set_var(array("weight_used_blck" => ""));
$t->set_block("page", "delivery_used", "delivery_used_blck");
$t->set_var(array("delivery_used_blck" => ""));
$t->set_block("page", "is_logged_in_horbartop", "is_logged_in_horbartop_blck");
$t->set_var(array("is_logged_in_horbartop_blck" => ""));
$t->set_var(array(
	"DOC_TITLE"			=> ov($t->get_var($DOC_TITLE)),
	"wwwroot"			=> $CFG->wwwroot,
	"images"			=> $CFG->images,
	"firstpage"			=> $CFG->firstpage,
	"cart_itemcount"		=> $CART->itemcount(),
	"cart_total"			=> $CART->total,
	"cart_ftotal"			=> formatted_price($CART->total),
	"current_stringtsf"		=> $stringtsf,
	"concatenation_checked_or"	=> $concatenation != "AND" ? "checked" : "",
	"concatenation_checked_and"	=> $concatenation == "AND" ? "checked" : "",
	"case_sensitive_checked"	=> $case_sensitive ? "checked" : ""
));
if (is_logged_in())
	$t->parse("is_logged_in_blck", "is_logged_in", true);
else
	$t->parse("is_not_logged_in_blck", "is_not_logged_in", true);
if ($SESSION["layersmenu_used"]) {
	$t->set_var("firstleveltable", $firstleveltable);
	$t->parse("layersmenu_used_blck", "layersmenu_used", true);
}
if ($SESSION["frames_used"])
	$t->parse("frames_used_blck", "frames_used", true);
else
	$t->parse("frames_not_used_blck", "frames_not_used", true);
if ($SESSION["layersmenu_used"])
	$t->parse("layersmenu_used_bis_blck", "layersmenu_used_bis", true);
else
	$t->parse("layersmenu_not_used_bis_blck", "layersmenu_not_used_bis", true);
if (is_logged_in() && has_priv("admin"))
	$t->parse("is_logged_in_admin_blck", "is_logged_in_admin", true);
if ($SESSION["weight_used"]) {
	$t->set_var(array(
		"cart_weight"	=> $CART->weight,
		"cart_fweight"	=> formatted_weight($CART->weight)
	));
	$t->parse("weight_used_blck", "weight_used", true);
}
if ($SESSION["delivery_used"]) {
	$t->set_var(array(
		"cart_delivery"		=> $CART->delivery,
		"cart_fdelivery"	=> formatted_price($CART->delivery)
	));
	$t->parse("delivery_used_blck", "delivery_used", true);
}
if (is_logged_in()) {
	$t->set_var(array(
		"session_user_firstname"	=> o($SESSION["user"]["firstname"]),
		"session_user_lastname"		=> o($SESSION["user"]["lastname"])
	));
	$t->parse("is_logged_in_horbartop_blck", "is_logged_in_horbartop", true);
}
$t->pparse("out", "page");

?>
